@@ -211,7 +211,7 @@ class Bucket(core.Construct):
             )
 
         # Limit access to CDN
-        if bucket_has_cdn:
+        if include_cdn:
 
             # Cloudflare doc https://support.cloudflare.com/hc/en-us/articles/360037983412-Configuring-an-Amazon-Web-Services-static-site-to-use-Cloudflare
             cloudflare_ips = [
